.. role:: raw-html-m2r(raw)
   :format: html


Here are some of CrabNet's paper figures. Please see the `CrabNet publication
<https://doi.org/10.1038/s41524-021-00545-1>`_ for further details. Additionally, a
comparison of CrabNet's performance against XGBoost is given.

Paper figures
-------------
:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure1_attention_plot_Al2O3.png?raw=true" alt="Al2O3 attention" width=600>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure2_aflow__Egap_ptable_0.png?raw=true" alt="Egap periodic" width=700>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure2_aflow__Egap_ptable_1.png?raw=true" alt="Egap periodic" width=700>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure2_aflow__Egap_ptable_2.png?raw=true" alt="Egap periodic" width=700>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure2_aflow__Egap_ptable_3.png?raw=true" alt="Egap periodic" width=700>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure2_aflow__Egap_ptable_average.png?raw=true" alt="Egap average" width=700>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure2.png?raw=true" alt="Egap periodic" width=700>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Figure4_binary_plot_Si-O.png?raw=true" alt="binary plot" width=500>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Table2_benchmark_metrics.png?raw=true" alt="benchmark metrics" width=700>`

:raw-html-m2r:`<br>`
:raw-html-m2r:`<img src="https://github.com/sparks-baird/crabnet/blob/main/figures/Table2_matbench_metrics.png?raw=true" alt="benchmark metrics" width=700>`


Extend Features
---------------
We also have the comparison between CrabNet and XGBoost for a dataset with a state
variable (applied load during hardness measurements).

CrabNet Parity
^^^^^^^^^^^^^^

.. raw:: html
   :file: extend_features/crabnet/parity_stderr_gcv.html

XGBoost Parity
^^^^^^^^^^^^^^

.. raw:: html
   :file: extend_features/xgboost/parity_stderr_gcv.html

CrabNet without load
^^^^^^^^^^^^^^^^^^^^

.. raw:: html
   :file: extend_features/without_load/crabnet/parity_stderr_gcv.html

XGBoost without load
^^^^^^^^^^^^^^^^^^^^

.. raw:: html
   :file: extend_features/without_load/xgboost/parity_stderr_gcv.html